from distutils.core import setup

setup(
     
     name = 'sxq',
     version = '1.0.0',
     py_modules = ['sxq'],
     author = 'sxq',
     author_email = '356834208@qq.com',
     url = 'www.helloworld.com',
     description = 'A simple printer of list',
     )
